@@ -48,12 +48,11 @@ def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True,
     count = 0
     for (i, j) in zip(text_lines_a, text_lines_b):
         a = i
-        b = j
-        #b = difflib.get_close_matches(a, text_lines_b, n=1)
-        #if b:
-        #    b = b[0]
-        #else:
-        #    b = ''
+        b = difflib.get_close_matches(a, text_lines_b, n=1)
+        if b:
+            b = b[0]
+        else:
+            b = ''
         ratio = fuzzyCompare.ratio(a, b)
         ratio_2 = fuzzyCompare.ratio(a, b, partial_ratio)
         if a != b:
@@ -133,6 +132,6 @@ def html_output(df, path_file_output):
 
 
 if __name__ == '__main__':
-    x = diffReport("Example/Input/SampleContract1.pdf", "Example/Input/SampleContract2.pdf", html_return=True)
+    x = diffReport("Example/Input/Default.pdf", "Example/Input/Default2.pdf", html_return=True)
 
     # print(x)
